# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/es_MX/__init__.py

person_formats_es_mx <- c(
  "{{first_names}} {{last_names1}} {{last_names2}}",
  "{{first_names1}} {{first_names2}} {{last_names}}",
  "{{first_names1}} {{first_names2}} {{last_names1}} {{last_names2}}",
  "{{first_names}} {{last_names}}",
  "{{prefixes}} {{first_names}} {{last_names}}"
)

person_first_names_es_mx <- c(
  "Abel",
  "Abelardo",
  "Abigail",
  "Abraham",
  "Abril",
  "Adalberto",
  "Ad\u00e1n",
  "Adela",
  "Adriana",
  "Aida",
  "Alejandra",
  "Agust\u00edn",
  "Alberto",
  "Aldonza",
  "Alicia",
  "Alta  Gracia",
  "Alonso",
  "Aldo",
  "Alejandro",
  "Alfonso",
  "Alfredo",
  "Alma",
  "Alvaro",
  "Amalia",
  "Amanda",
  "Amador",
  "Amelia",
  "Ana",
  "Anabel",
  "Ana Luisa",
  "Ana Mar\u00eda",
  "Anel",
  "Andrea",
  "Andr\u00e9s",
  "\u00c1ngel",
  "\u00c1ngela",
  "Ang\u00e9lica",
  "Antonia",
  "Antonio",
  "Araceli",
  "Arcelia",
  "Ariadna",
  "Armando",
  "Arturo",
  "Asunci\u00f3n",
  "Augusto",
  "Aurora",
  "Aurelio",
  "Barbara",
  "Beatriz",
  "Berta",
  "Benito",
  "Benjam\u00edn",
  "Bernardo",
  "Bernab\u00e9",
  "Bianca",
  "Blanca",
  "Bruno",
  "Camila",
  "Camilo",
  "Caridad",
  "Carla",
  "Carlos",
  "Carlota",
  "Carmen",
  "Carolina",
  "Catalina",
  "C\u00e9sar",
  "Cecilia",
  "Celia",
  "Citlali",
  "Clara",
  "Claudia",
  "Claudio",
  "Clemente",
  "Concepci\u00f3n",
  "Conchita",
  "Cornelio",
  "Cristian",
  "Cristal",
  "Cristina",
  "Cristobal",
  "Cynthia",
  "Dalia",
  "Daniel",
  "Daniela",
  "Dar\u00edo",
  "David",
  "D\u00e9bora",
  "Delia",
  "Diana",
  "Diego",
  "Dolores",
  "Dulce",
  "Dulce Mar\u00eda",
  "Eduardo",
  "Elena",
  "Elias",
  "Elisa",
  "Eloisa",
  "Elsa",
  "Elvia",
  "Elvira",
  "Eloy",
  "Emilia",
  "Emiliano",
  "Emilio",
  "Enrique",
  "Eric",
  "Ernesto",
  "Esmeralda",
  "Esteban",
  "Estefan\u00eda",
  "Estela",
  "Esparta",
  "Espartaco",
  "Esperanza",
  "Estela",
  "Esther",
  "Eugenia",
  "Eugenio",
  "Eva",
  "Evelio",
  "Fabiola",
  "Federico",
  "Felipe",
  "Fernando",
  "Felix",
  "Fidel",
  "Flavio",
  "Florencia",
  "Francisco",
  "Francisco Javier",
  "Francisca",
  "Frida",
  "Gabino",
  "Gabriela",
  "Gabriel",
  "Genaro",
  "Georgina",
  "Gerardo",
  "Ger\u00f3nimo",
  "Germ\u00e1n",
  "Gilberto",
  "Guillermina",
  "Gloria",
  "Gonzalo",
  "Graciela",
  "Gregorio",
  "Guillermo",
  "Guadalupe",
  "Gustavo",
  "H\u00e9ctor",
  "Helena",
  "Hermelinda",
  "Hern\u00e1n",
  "Hilda",
  "Homero",
  "Horacio",
  "Hugo",
  "Humberto",
  "Ignacio",
  "Ilse",
  "Indira",
  "In\u00e9s",
  "Irene",
  "Irma",
  "Itzel",
  "Isaac",
  "Isabel",
  "Isabela",
  "Israel",
  "Iv\u00e1n",
  "Ivonne",
  "Jacinto",
  "Jacobo",
  "Jaime",
  "Javier",
  "Jaqueline",
  "Jer\u00f3nimo",
  "Jes\u00fas",
  "Joaqu\u00edn",
  "Jon\u00e1s",
  "Jorge",
  "Jorge Luis",
  "Jos",
  "Jos\u00e9",
  "Josefina",
  "Jos\u00e9 Carlos",
  "Jos\u00e9 Eduardo",
  "Jos\u00e9 Emilio",
  "Jos\u00e9 Luis",
  "Jos\u00e9 Manu\u00e9l",
  "Jos\u00e9 Mar\u00eda",
  "Juan",
  "Juana",
  "Juan Carlos",
  "Judith",
  "Julia",
  "Julio",
  "Julio C\u00e9sar",
  "Laura",
  "Leonardo",
  "Leonel",
  "Leonor",
  "Karla",
  "Karina",
  "Leticia",
  "Lorenzo",
  "Lucas",
  "Lilia",
  "Liliana",
  "Linda",
  "Lorena",
  "Lourdes",
  "Luc\u00eda",
  "Luisa",
  "Luz",
  "Luis",
  "Luis Miguel",
  "Luis Manuel",
  "Magdalena",
  "Manuel",
  "Marco Antonio",
  "Marcela",
  "Marcos",
  "Margarita",
  "Mar\u00eda",
  "Marisela",
  "Marisol",
  "Mar\u00eda del Carmen",
  "Mar\u00eda Cristina",
  "Mar\u00eda Elena",
  "Mar\u00eda Eugenia",
  "Mar\u00eda Jos\u00e9",
  "Mar\u00eda Luisa",
  "Mar\u00eda Teresa",
  "Marisol",
  "Martha",
  "Mayte",
  "Mariano",
  "Mariana",
  "Mario",
  "Mart\u00edn",
  "Mateo",
  "Mauro",
  "Mauricio",
  "Maximiliano",
  "Mercedes",
  "Micaela",
  "Minerva",
  "Mitzy",
  "Miguel",
  "Miguel \u00c1ngel",
  "Miriam",
  "Modesto",
  "M\u00f3nica",
  "Nadia",
  "Natalia",
  "Natividad",
  "Nancy",
  "Nayeli",
  "Nelly",
  "Noelia",
  "Noem\u00ed",
  "Norma",
  "Nicol\u00e1s",
  "Octavio",
  "Ofelia",
  "Olivia",
  "\u00d3liver",
  "Olga",
  "\u00d3scar",
  "Oswaldo",
  "Omar",
  "Pablo",
  "Paola",
  "Patricia",
  "Pamela",
  "Patricio",
  "Pascual",
  "Paulina",
  "Pedro",
  "Perla",
  "Pilar",
  "Porfirio",
  "Rafa\u00e9l",
  "Ramiro",
  "Ram\u00f3n",
  "Ra\u00fal",
  "Raquel",
  "Rebeca",
  "Reina",
  "Renato",
  "Ren\u00e9",
  "Reynaldo",
  "Ricardo",
  "Roberto",
  "Rodolfo",
  "Roc\u00edo",
  "Rodrigo",
  "Rolando",
  "Rosa",
  "Rosalia",
  "Rosario",
  "Rub\u00e9n",
  "Rufino",
  "Ruby",
  "Salvador",
  "Salma",
  "Samuel",
  "Sandra",
  "Santiago",
  "Sara",
  "Sessa",
  "Sergio",
  "Seraf\u00edn",
  "Silvano",
  "Silvia",
  "Sof\u00eda",
  "Socorro",
  "Soledad",
  "Sonia",
  "Susana",
  "Tania",
  "Teresa",
  "Teodoro",
  "Timoteo",
  "Tom\u00e1s",
  "Trinidad",
  "Ver\u00f3nica",
  "Vicente",
  "Violeta",
  "Uriel",
  "\u00darsula",
  "Vanesa",
  "V\u00edctor",
  "Victoria",
  "Virginia",
  "Wilfrido",
  "Wendolin",
  "Yeni",
  "Yolanda",
  "Yuridia",
  "Zacar\u00edas",
  "Zeferino",
  "Zo\u00e9"
)

person_last_names_es_mx <- c(
  "Abrego",
  "Abreu",
  "Acevedo",
  "Acosta",
  "Acu\u00f1a",
  "Adame",
  "Aguayo",
  "Aguilar",
  "Aguilera",
  "Aguirre",
  "Alarc\u00f3n",
  "Alba",
  "Alcala",
  "Alc\u00e1ntar",
  "Alcaraz",
  "Alejandro",
  "Alem\u00e1n",
  "Alfaro",
  "Almanza",
  "Almaraz",
  "Almonte",
  "Alonso",
  "Alonzo",
  "Altamirano",
  "Alva",
  "Alvarado",
  "Alvarez",
  "Amador",
  "Amaya",
  "Anaya",
  "Anguiano",
  "Angulo",
  "Aparicio",
  "Apodaca",
  "Aponte",
  "Arag\u00f3n",
  "Aranda",
  "Arce",
  "Archuleta",
  "Arellano",
  "Arenas",
  "Arevalo",
  "Arguello",
  "Arias",
  "Armas",
  "Armend\u00e1riz",
  "Armenta",
  "Arredondo",
  "Arreola",
  "Arriaga",
  "Arroyo",
  "Arteaga",
  "\u00c1valos",
  "\u00c1vila",
  "Avil\u00e9s",
  "Ayala",
  "Baca",
  "Badillo",
  "B\u00e1ez",
  "Baeza",
  "Bahena",
  "Balderas",
  "Ballesteros",
  "Ba\u00f1uelos",
  "Barajas",
  "Barela",
  "Barrag\u00e1n",
  "Barraza",
  "Barrera",
  "Barreto",
  "Barrientos",
  "Barrios",
  "Batista",
  "Becerra",
  "Beltr\u00e1n",
  "Benavides",
  "Benav\u00eddez",
  "Ben\u00edtez",
  "Berm\u00fadez",
  "Bernal",
  "Berr\u00edos",
  "B\u00e9tancourt",
  "Blanco",
  "Bonilla",
  "Borrego",
  "Botello",
  "Bravo",
  "Briones",
  "Brise\u00f1o",
  "Brito",
  "Bueno",
  "Burgos",
  "Bustamante",
  "Bustos",
  "Caballero",
  "Cab\u00e1n",
  "Cabrera",
  "Cadena",
  "Caldera",
  "Calder\u00f3n",
  "Calvillo",
  "Camacho",
  "Camarillo",
  "Campos",
  "Canales",
  "Candelaria",
  "Cano",
  "Cant\u00fa",
  "Caraballo",
  "Carbajal",
  "Cardenas",
  "Cardona",
  "Carmona",
  "Carranza",
  "Carrasco",
  "Carre\u00f3n",
  "Carrera",
  "Carrero",
  "Carrillo",
  "Carri\u00f3n",
  "Carvajal",
  "Casanova",
  "Casares",
  "Cas\u00e1rez",
  "Casas",
  "Casillas",
  "Casta\u00f1eda",
  "Castellanos",
  "Castillo",
  "Castro",
  "Cavazos",
  "Cazares",
  "Ceballos",
  "Cedillo",
  "Ceja",
  "Centeno",
  "Cepeda",
  "Cervantes",
  "Cerv\u00e1ntez",
  "Chac\u00f3n",
  "Chapa",
  "Chavarr\u00eda",
  "Ch\u00e1vez",
  "Cintr\u00f3n",
  "Cisneros",
  "Collado",
  "Collazo",
  "Col\u00f3n",
  "Colunga",
  "Concepci\u00f3n",
  "Contreras",
  "Cordero",
  "C\u00f3rdova",
  "Cornejo",
  "Corona",
  "Coronado",
  "Corral",
  "Corrales",
  "Correa",
  "Cort\u00e9s",
  "Cortez",
  "Cotto",
  "Covarrubias",
  "Crespo",
  "Cruz",
  "Cuellar",
  "Curiel",
  "D\u00e1vila",
  "de Anda",
  "de Jes\u00fas",
  "de la Cr\u00faz",
  "de la Fuente",
  "de la Garza",
  "de la O",
  "de la Rosa",
  "de la Torre",
  "de Le\u00f3n",
  "Delgadillo",
  "Delgado",
  "del R\u00edo",
  "del Valle",
  "D\u00edaz",
  "Dom\u00ednguez",
  "Duarte",
  "Due\u00f1as",
  "Dur\u00e1n",
  "Echeverr\u00eda",
  "Elizondo",
  "Enr\u00edquez",
  "Escalante",
  "Escamilla",
  "Escobar",
  "Escobedo",
  "Esparza",
  "Espinal",
  "Espino",
  "Espinosa",
  "Espinoza",
  "Esquibel",
  "Esquivel",
  "Est\u00e9vez",
  "Estrada",
  "Fajardo",
  "Far\u00edas",
  "Feliciano",
  "Fern\u00e1ndez",
  "Ferrer",
  "Fierro",
  "Figueroa",
  "Flores",
  "Fl\u00f3rez",
  "Fonseca",
  "Franco",
  "Fr\u00edas",
  "Fuentes",
  "Gait\u00e1n",
  "Galarza",
  "Galindo",
  "Gallardo",
  "Gallegos",
  "Galv\u00e1n",
  "G\u00e1lvez",
  "Gamboa",
  "Gamez",
  "Gaona",
  "Garay",
  "Garc\u00eda",
  "Garibay",
  "Garica",
  "Garrido",
  "Garza",
  "Gast\u00e9lum",
  "Gayt\u00e1n",
  "Gil",
  "Gir\u00f3n",
  "God\u00ednez",
  "Godoy",
  "G\u00f3mez",
  "Gonzales",
  "Gonz\u00e1lez",
  "Gollum",
  "Gracia",
  "Granado",
  "Granados",
  "Griego",
  "Grijalva",
  "Guajardo",
  "Guardado",
  "Guerra",
  "Guerrero",
  "Guevara",
  "Guillen",
  "Gurule",
  "Guti\u00e9rrez",
  "Guzm\u00e1n",
  "Haro",
  "Henr\u00edquez",
  "Heredia",
  "Hern\u00e1dez",
  "Hernandes",
  "Hern\u00e1ndez",
  "Herrera",
  "Hidalgo",
  "Hinojosa",
  "Holgu\u00edn",
  "Huerta",
  "Hurtado",
  "Ibarra",
  "Iglesias",
  "Irizarry",
  "Jaime",
  "Jaimes",
  "J\u00e1quez",
  "Jaramillo",
  "Jasso",
  "Jim\u00e9nez",
  "Jim\u00ednez",
  "Ju\u00e1rez",
  "Jurado",
  "Laboy",
  "Lara",
  "Laureano",
  "Leal",
  "Lebr\u00f3n",
  "Ledesma",
  "Leiva",
  "Lemus",
  "Le\u00f3n",
  "Lerma",
  "Leyva",
  "Lim\u00f3n",
  "Linares",
  "Lira",
  "Llamas",
  "Loera",
  "Lomeli",
  "Longoria",
  "L\u00f3pez",
  "Lovato",
  "Loya",
  "Lozada",
  "Lozano",
  "Lucero",
  "Lucio",
  "Luevano",
  "Lugo",
  "Luna",
  "Mac\u00edas",
  "Madera",
  "Madrid",
  "Madrigal",
  "Maestas",
  "Maga\u00f1a",
  "Malave",
  "Maldonado",
  "Manzanares",
  "Mares",
  "Mar\u00edn",
  "M\u00e1rquez",
  "Marrero",
  "Marroqu\u00edn",
  "Mart\u00ednez",
  "Mascare\u00f1as",
  "Mata",
  "Mateo",
  "Mat\u00edas",
  "Matos",
  "Maya",
  "Mayorga",
  "Medina",
  "Medrano",
  "Mej\u00eda",
  "Mel\u00e9ndez",
  "Melgar",
  "Mena",
  "Menchaca",
  "M\u00e9ndez",
  "Mendoza",
  "Men\u00e9ndez",
  "Meraz",
  "Mercado",
  "Merino",
  "Mesa",
  "Meza",
  "Miramontes",
  "Miranda",
  "Mireles",
  "Mojica",
  "Molina",
  "Mondrag\u00f3n",
  "Monroy",
  "Montalvo",
  "Monta\u00f1ez",
  "Monta\u00f1o",
  "Montemayor",
  "Montenegro",
  "Montero",
  "Montes",
  "Montez",
  "Montoya",
  "Mora",
  "Morales",
  "Moreno",
  "Mota",
  "Moya",
  "Mungu\u00eda",
  "Mu\u00f1iz",
  "Mu\u00f1oz",
  "Murillo",
  "Muro",
  "N\u00e1jera",
  "Naranjo",
  "Narv\u00e1ez",
  "Nava",
  "Navarrete",
  "Navarro",
  "Nazario",
  "Negrete",
  "Negr\u00f3n",
  "Nev\u00e1rez",
  "Nieto",
  "Nieves",
  "Ni\u00f1o",
  "Noriega",
  "N\u00fa\u00f1ez",
  "Ocampo",
  "Ocasio",
  "Ochoa",
  "Ojeda",
  "Olivares",
  "Oliv\u00e1rez",
  "Olivas",
  "Olivera",
  "Olivo",
  "Olmos",
  "Olvera",
  "Ontiveros",
  "Oquendo",
  "Ord\u00f3\u00f1ez",
  "Orellana",
  "Ornelas",
  "Orosco",
  "Orozco",
  "Orta",
  "Ortega",
  "Ortiz",
  "Osorio",
  "Otero",
  "Ozuna",
  "Pab\u00f3n",
  "Pacheco",
  "Padilla",
  "Padr\u00f3n",
  "P\u00e1ez",
  "Palacios",
  "Palomino",
  "Palomo",
  "Pantoja",
  "Paredes",
  "Parra",
  "Partida",
  "Pati\u00f1o",
  "Paz",
  "Pedraza",
  "Pedroza",
  "Pelayo",
  "Pe\u00f1a",
  "Perales",
  "Peralta",
  "Perea",
  "Peres",
  "P\u00e9rez",
  "Pichardo",
  "Pi\u00f1a",
  "Pineda",
  "Pizarro",
  "Polanco",
  "Ponce",
  "Porras",
  "Portillo",
  "Posada",
  "Prado",
  "Preciado",
  "Prieto",
  "Puente",
  "Puga",
  "Pulido",
  "Quesada",
  "Quezada",
  "Qui\u00f1ones",
  "Qui\u00f1\u00f3nez",
  "Quintana",
  "Quintanilla",
  "Quintero",
  "Quiroz",
  "Rael",
  "Ram\u00edrez",
  "Ram\u00f3n",
  "Ramos",
  "Rangel",
  "Rasc\u00f3n",
  "Raya",
  "Razo",
  "Regalado",
  "Rend\u00f3n",
  "Renter\u00eda",
  "Res\u00e9ndez",
  "Reyes",
  "Reyna",
  "Reynoso",
  "Rico",
  "Rinc\u00f3n",
  "Riojas",
  "R\u00edos",
  "Rivas",
  "Rivera",
  "Rivero",
  "Robledo",
  "Robles",
  "Rocha",
  "Rodarte",
  "Rodr\u00edgez",
  "Rodr\u00edguez",
  "Rodr\u00edquez",
  "Rojas",
  "Rojo",
  "Rold\u00e1n",
  "Rol\u00f3n",
  "Romero",
  "Romo",
  "Roque",
  "Rosado",
  "Rosales",
  "Rosario",
  "Rosas",
  "Roybal",
  "Rubio",
  "Ruelas",
  "Ruiz",
  "Saavedra",
  "S\u00e1enz",
  "Saiz",
  "Salas",
  "Salazar",
  "Salcedo",
  "Salcido",
  "Salda\u00f1a",
  "Saldivar",
  "Salgado",
  "Salinas",
  "Samaniego",
  "Sanabria",
  "Sanches",
  "S\u00e1nchez",
  "Sandoval",
  "Santacruz",
  "Santana",
  "Santiago",
  "Santill\u00e1n",
  "Sarabia",
  "Sauceda",
  "Saucedo",
  "Segovia",
  "Segura",
  "Sep\u00falveda",
  "Serna",
  "Serrano",
  "Serrato",
  "Sevilla",
  "Sierra",
  "Sisneros",
  "Solano",
  "Sol\u00eds",
  "Soliz",
  "Solorio",
  "Solorzano",
  "Soria",
  "Sosa",
  "Sotelo",
  "Soto",
  "Su\u00e1rez",
  "Tafoya",
  "Tamayo",
  "Tamez",
  "Tapia",
  "Tejada",
  "Tejeda",
  "T\u00e9llez",
  "Tello",
  "Ter\u00e1n",
  "Terrazas",
  "Tijerina",
  "Tirado",
  "Toledo",
  "Toro",
  "Torres",
  "T\u00f3rrez",
  "Tovar",
  "Trejo",
  "Trevi\u00f1o",
  "Trujillo",
  "Ulibarri",
  "Ulloa",
  "Urbina",
  "Ure\u00f1a",
  "Ur\u00edas",
  "Uribe",
  "Urrutia",
  "Vaca",
  "Valadez",
  "Vald\u00e9s",
  "Valdez",
  "Valdivia",
  "Valencia",
  "Valent\u00edn",
  "Valenzuela",
  "Valladares",
  "Valle",
  "Vallejo",
  "Valles",
  "Valverde",
  "Vanegas",
  "Varela",
  "Vargas",
  "V\u00e1squez",
  "V\u00e1zquez",
  "Vega",
  "Vela",
  "Velasco",
  "Vel\u00e1squez",
  "Vel\u00e1zquez",
  "V\u00e9lez",
  "V\u00e9liz",
  "Venegas",
  "Vera",
  "Verdugo",
  "Verduzco",
  "Vergara",
  "Viera",
  "Vigil",
  "Villa",
  "Villag\u00f3mez",
  "Villalobos",
  "Villalpando",
  "Villanueva",
  "Villareal",
  "Villarreal",
  "Villase\u00f1or",
  "Villegas",
  "Y\u00e1\u00f1ez",
  "Ybarra",
  "Zambrano",
  "Zamora",
  "Zamudio",
  "Zapata",
  "Zaragoza",
  "Zarate",
  "Zavala",
  "Zayas",
  "Zedillo",
  "Zelaya",
  "Zepeda",
  "Z\u00fa\u00f1iga"
)

person_prefixes_es_mx <- c("Sr(a).", "Dr.", "Mtro.", "Lic.", "Ing.")

person_es_mx <- list(
  first_names = person_first_names_es_mx,
  last_names = person_last_names_es_mx,
  prefixes = person_prefixes_es_mx
)

#' @title Person Provider for Spanish (Mexico)
#' @inherit PersonProvider description details return
#' @export
#' @family es
#' @family MX
#' @details Note for female and male components that we fall back on generic
#' versions if the locale
#' doesn't provide a male/female version.
#' e.g., if no female first name we use first
#' name
#' @examples
#' x <- PersonProvider_de_AT$new()
#' x$locale
#' x$render()
#' x$first_name()
#' x$first_name_female()
#' x$first_name_male()
#' x$last_name()
#' x$last_name_female()
#' x$last_name_male()
PersonProvider_es_MX <- R6::R6Class(
  "PersonProvider_es_MX",
  inherit = PersonProvider,
  private = list(
    formats = person_formats_es_mx,
    persons = person_es_mx,
    locale_ = "es_MX"
  )
)
